sshutil

package
v0.0.0-...-8bbf13e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 13, 2026 License: LGPL-2.1 Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Connect

func Connect(ctx context.Context, host string, config *ssh.ClientConfig) (client *ssh.Client, err error)

func GenerateKeyPair

func GenerateKeyPair() ([]byte, []byte, error)

GenerateKeyPair generates a new ed25519 ssh key pair, and returns the private key and the public key respectively.

Experimental: `exp` package is experimental, breaking changes may occur within minor releases.

func GeneratePublicKey

func GeneratePublicKey(privBytes []byte) ([]byte, error)

GeneratePublicKey generate a public key from the provided private key.

Experimental: `exp` package is experimental, breaking changes may occur within minor releases.

func GetPublicKeyFingerprint

func GetPublicKeyFingerprint(pubBytes []byte) (string, error)

GetPublicKeyFingerprint generate the finger print for the provided public key.

Experimental: `exp` package is experimental, breaking changes may occur within minor releases.

func NewNullReader

func NewNullReader() io.Reader

func Run

func Run(client *ssh.Client, cmd string, stdin io.Reader) ([]byte, error)

func RunStdout

func RunStdout(client *ssh.Client, cmd string, stdin io.Reader) error

Types

This section is empty.

Jump to