Documentation
¶
Index ¶
- func Connect(ctx context.Context, host string, config *ssh.ClientConfig) (client *ssh.Client, err error)
- func GenerateKeyPair() ([]byte, []byte, error)
- func GeneratePublicKey(privBytes []byte) ([]byte, error)
- func GetPublicKeyFingerprint(pubBytes []byte) (string, error)
- func NewNullReader() io.Reader
- func Run(client *ssh.Client, cmd string, stdin io.Reader) ([]byte, error)
- func RunStdout(client *ssh.Client, cmd string, stdin io.Reader) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GenerateKeyPair ¶
GenerateKeyPair generates a new ed25519 ssh key pair, and returns the private key and the public key respectively.
Experimental: `exp` package is experimental, breaking changes may occur within minor releases.
func GeneratePublicKey ¶
GeneratePublicKey generate a public key from the provided private key.
Experimental: `exp` package is experimental, breaking changes may occur within minor releases.
func GetPublicKeyFingerprint ¶
GetPublicKeyFingerprint generate the finger print for the provided public key.
Experimental: `exp` package is experimental, breaking changes may occur within minor releases.
func NewNullReader ¶
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.